@@ -4,15 +4,25 @@ from collections.abc import Generator
 from contextlib import contextmanager
 
 import httpx
+from connector_sdk_types.generated import ErrorCode
 from gql.transport.httpx import HTTPXAsyncTransport as GqlHTTPXAsyncTransport
 from urllib3.util.url import Url, parse_url
 
-from connector.generated import ErrorCode
 from connector.oai.errors import ConnectorError
+from connector.response_logging import (
+    CONTENT_MAX_LENGTH,
+    ResponseLogRecord,
+    create_response_logger,
+    redact_sensitive_data,
+)
 
 logger = logging.getLogger("integration-connectors.sdk")
+GLOBAL_REQUEST_TIMEOUT = httpx.Timeout(300.0)  # 5 minutes
 
 
+# Create response logger (same as original)
+response_logger = create_response_logger("integration-connectors.sdk.api_response")
+
 LUMOS_PROXY_URL: contextvars.ContextVar[str | None] = contextvars.ContextVar(
     "LUMOS_PROXY_URL", default=None
 )
@@ -51,6 +61,43 @@ def get_proxy_headers() -> httpx.Headers:
     return LUMOS_PROXY_HEADERS.get()
 
 
+def log_response(response: httpx.Response):
+    """Log HTTP response (restored original httpx_rewrite logic)"""
+    content = response.text
+
+    if len(content) > CONTENT_MAX_LENGTH:
+        content = content[: CONTENT_MAX_LENGTH // 2] + " ... " + content[-CONTENT_MAX_LENGTH // 2 :]
+
+    content = redact_sensitive_data(content)
+    url = redact_sensitive_data(str(response.url))
+    headers = redact_sensitive_data(dict(response.headers))
+
+    content_hash = ""
+    try:
+        content_hash = str(hash(content))
+    except Exception:
+        content_hash = "hashing failed"
+
+    record = ResponseLogRecord(
+        name=response_logger.name,
+        level=response_logger.level,
+        pathname="",
+        lineno=0,
+        msg=f"Got an external response: [{response.request.method}][{response.status_code}] {url}",
+        args=(),
+        exc_info=None,
+    )
+
+    record.method = str(response.request.method)
+    record.url = url
+    record.status_code = response.status_code
+    record.headers = headers
+    record.content = content
+    record.content_hash = content_hash
+
+    response_logger.handle(record)
+
+
 class AsyncClient(httpx.AsyncClient):
     """
     A slightly modified version of httpx.AsyncClient, that may rewrite requests to go to a proxy.
@@ -70,13 +117,20 @@ class AsyncClient(httpx.AsyncClient):
     def will_rewrite_request(self) -> bool:
         return bool(get_proxy_url())
 
+    def __init__(self, *args, **kwargs):
+        if "timeout" not in kwargs:
+            kwargs["timeout"] = GLOBAL_REQUEST_TIMEOUT
+        super().__init__(*args, **kwargs)
+
     async def send(self, request: httpx.Request, **kwargs) -> httpx.Response:
         proxy_host = get_proxy_url()
         if proxy_host:
             logger.warning("Proxying all requests to %s", proxy_host)
             override = parse_url(proxy_host)
         else:
-            return await super().send(request, **kwargs)
+            response = await super().send(request, **kwargs)
+            log_response(response)
+            return response
 
         # Update request URL
         url = str(request.url)
@@ -113,9 +167,9 @@ class AsyncClient(httpx.AsyncClient):
         logger.debug("Sending request to proxy: %s", new_request.url)
         logger.debug("Request method: %s", new_request.method)
         response = await super().send(new_request, **kwargs)
-        logger.debug("Request headers: %s", response.request.headers)
+        logger.debug("Request headers: %s", [(k, v) for k, v in response.request.headers.items()])
         logger.debug("Request body: %s", response.request.content)
-        logger.debug("Response headers: %s", response.headers)
+        logger.debug("Response headers: %s", [(k, v) for k, v in response.headers.items()])
         truncated_response = response.text[:1000] + "..." if len(response.text) > 1000 else ""
         logger.debug("Response: %s", truncated_response)
         logger.debug("Response status code: %s", response.status_code)
