@@ -31,9 +31,7 @@ import re
 import typing as t
 from dataclasses import asdict, dataclass
 
-from pydantic import BaseModel, ValidationError
-
-from connector.generated import (
+from connector_sdk_types.generated import (
     AppCategory,
     AuthCredential,
     AuthModel,
@@ -51,9 +49,12 @@ from connector.generated import (
     OAuthClientCredential,
     OAuthCredential,
     ResourceType,
+    ServiceAccountCredential,
     StandardCapabilityName,
     TokenCredential,
 )
+from pydantic import BaseModel, ValidationError
+
 from connector.oai.capability import (
     CapabilityCallableProto,
     capability_requires_authentication,
@@ -66,6 +67,7 @@ from connector.oai.modules.base_module import BaseIntegrationModule
 from connector.oai.modules.info_module import InfoModule
 from connector.oai.modules.oauth_module import OAuthModule
 from connector.oai.modules.oauth_module_types import OAuthConfig, OAuthSettings
+from connector.utils.validation_utils import get_missing_field_titles
 
 AuthSetting: t.TypeAlias = (
     type[OAuthCredential]
@@ -74,6 +76,7 @@ AuthSetting: t.TypeAlias = (
     | type[BasicCredential]
     | type[TokenCredential]
     | type[JWTCredential]
+    | type[ServiceAccountCredential]
 )
 
 
@@ -83,6 +86,7 @@ AUTH_TYPE_MAP = {
     AuthModel.BASIC: BasicCredential,
     AuthModel.TOKEN: TokenCredential,
     AuthModel.JWT: JWTCredential,
+    AuthModel.SERVICE_ACCOUNT: ServiceAccountCredential,
 }
 
 
@@ -142,6 +146,12 @@ class DescriptionData:
     categories: list[AppCategory]
     description: str | None = None
     logo_url: str | None = None
+    """
+    The domain name of the company or organization that provides the application.
+    Used to identify the external vendor associated with the app.
+    For Example: "aws.amazon.com" for an "aws-sso" app.
+    """
+    app_vendor_domain: str | None = None
 
 
 @dataclass
@@ -499,6 +509,9 @@ class Integration:
                 elif connector_credential.type == AuthModel.JWT:
                     if not credential.jwt:
                         missing = "jwt"
+                elif connector_credential.type == AuthModel.SERVICE_ACCOUNT:
+                    if not credential.service_account:
+                        missing = "service_account"
                 if missing != "Nothing":
                     return ErrorResponse(
                         is_error=True,
@@ -605,11 +618,18 @@ class Integration:
         else:
             try:
                 self.settings_model.model_validate(request.settings)
-            except ValidationError:
+            except ValidationError as e:
+                msg = "Invalid settings passed on request."
+
+                # Check if the validation error is due to missing required fields
+                missing_titles, _ = get_missing_field_titles(e, self.settings_model)
+                if missing_titles:
+                    msg += " Missing required settings: " + ", ".join(missing_titles)
+
                 return ErrorResponse(
                     is_error=True,
                     error=Error(
-                        message="Invalid settings passed on request",
+                        message=msg,
                         error_code=ErrorCode.BAD_REQUEST,
                         app_id=self.app_id,
                     ),
@@ -687,6 +707,7 @@ class Integration:
                 version=self.version,
                 capabilities=capability_names,
                 capability_schema=capability_schema,
+                app_vendor_domain=self.description_data.app_vendor_domain,
                 logo_url=self.description_data.logo_url,
                 user_friendly_name=self.description_data.user_friendly_name,
                 description=self.description_data.description,
