@@ -1,10 +1,7 @@
 from enum import Enum
 from typing import TYPE_CHECKING, Any, cast
 
-from pydantic import BaseModel
-from typing_extensions import assert_never
-
-from connector.generated import (
+from connector_sdk_types.generated import (
     AppInfo,
     AppInfoRequest,
     AppInfoResponse,
@@ -17,12 +14,14 @@ from connector.generated import (
     OAuthAuthorization,
     OAuthClientCredentialAuthentication,
     OAuthClientCredentialAuthorization,
+    ServiceAccountCredential,
     StandardCapabilityName,
     TokenAuthentication,
 )
-from connector.oai.capability import (
-    generate_capability_schema,
-)
+from pydantic import BaseModel
+from typing_extensions import assert_never
+
+from connector.oai.capability import generate_capability_schema
 from connector.oai.modules.base_module import BaseIntegrationModule
 from connector.oai.modules.oauth_module_types import OAuthConfig, OAuthFlowType, OAuthSettings
 
@@ -44,6 +43,7 @@ AUTH_TYPE_MAPPING = {
     AuthModel.BASIC: (BasicAuthentication, None),
     AuthModel.TOKEN: (TokenAuthentication, None),
     AuthModel.JWT: (JWTCredential, None),
+    AuthModel.SERVICE_ACCOUNT: (ServiceAccountCredential, None),
 }
 
 OAS_FLOW_TYPE_MAPPING = {
@@ -202,7 +202,7 @@ class InfoModule(BaseIntegrationModule):
                 "properties": {
                     "request": request_payload_schema,
                     "settings": {
-                        "$ref": f"#/components/schemas/{self.integration.settings_model.__name__}"
+                        "$ref": "#/components/schemas/Settings"
                         if hasattr(self.integration, "settings_model")
                         else {"type": "object", "example": "{}"},
                     },
@@ -511,6 +511,14 @@ class InfoModule(BaseIntegrationModule):
                         "name": "Authorization",
                         "description": "JWT Token for authentication",
                     }
+                case AuthModel.SERVICE_ACCOUNT:
+                    # TODO: this might not be 100% accurate
+                    security_schemas[security_schema_name] = {
+                        "type": "apiKey",
+                        "in": "header",
+                        "name": "Authorization",
+                        "description": "Service Account Token for authentication",
+                    }
                 case _:
                     assert_never(auth_type)
 
@@ -578,6 +586,7 @@ class InfoModule(BaseIntegrationModule):
             "info": {
                 "x-app-id": app.app_id,
                 "x-app-logo-url": app.description_data.logo_url,
+                "x-app-vendor-domain": app.description_data.app_vendor_domain,
                 "title": app.description_data.user_friendly_name,
                 "description": app.description_data.description,
                 "version": app.version,
@@ -683,7 +692,7 @@ class InfoModule(BaseIntegrationModule):
         return credentials_dump
 
     def _get_model_extended_json_schema(self, model: type[BaseModel]) -> dict[str, Any]:
-        json_schema = model.model_json_schema()
+        json_schema = model.model_json_schema(ref_template="#/components/schemas/{model}")
         field_order = list(model.model_fields.keys())
         json_schema["x-field_order"] = field_order
         return json_schema
@@ -758,9 +767,9 @@ class InfoModule(BaseIntegrationModule):
         if not hasattr(model, "model_json_schema"):
             raise ValueError(f"Model {name} does not have a model_json_schema method")
 
-        schema = model.model_json_schema()
-        spec["components"]["schemas"][name] = schema
-        used_refs.add(name)
+        schema = self._get_model_extended_json_schema(model)
+        spec["components"]["schemas"]["Settings"] = schema
+        used_refs.add("Settings")
 
         # Clean up
         if "$defs" in schema:
