@@ -4,11 +4,9 @@ import logging
 import os
 from collections.abc import Callable, Sequence
 from typing import TYPE_CHECKING, Any
+from urllib.parse import quote_plus, urlencode
 
-from httpx import BasicAuth
-
-from connector.auth_helper import parse_auth_code_and_redirect_uri
-from connector.generated import (
+from connector_sdk_types.generated import (
     AuthorizationUrl,
     ErrorCode,
     GetAuthorizationUrlRequest,
@@ -22,6 +20,9 @@ from connector.generated import (
     RefreshAccessTokenResponse,
     StandardCapabilityName,
 )
+from httpx import BasicAuth
+
+from connector.auth_helper import parse_auth_code_and_redirect_uri
 from connector.httpx_rewrite import AsyncClient
 from connector.oai.capability import AuthRequest
 from connector.oai.errors import ConnectorError
@@ -348,18 +349,19 @@ class OAuthModule(BaseIntegrationModule):
             )
             state = args.request.state
 
-            authorization_url = (
-                f"{url}?"
-                f"client_id={client_id}&"
-                f"response_type=code&"
-                f"scope={scope}&"
-                f"redirect_uri={redirect_uri}&"
-                f"state={state}"
-            )
+            params = {
+                "client_id": client_id,
+                "response_type": "code",
+                "scope": scope,
+                "redirect_uri": redirect_uri,
+                "state": state,
+            }
+
+            authorization_url = f"{url}?{urlencode(params, quote_via=quote_plus)}"
 
             if settings.pkce:
                 code_verifier, code_challenge = self._generate_code_challenge()
-                authorization_url += f"&code_challenge={code_challenge}"
+                authorization_url += f"&code_challenge={quote_plus(code_challenge)}"
                 authorization_url += "&code_challenge_method=S256"
             else:
                 code_verifier = None
