@@ -1,6 +1,6 @@
 import os
 import re
-from argparse import Namespace, ArgumentParser, _SubParsersAction
+from argparse import Namespace, ArgumentParser
 from pathlib import Path
 
 TEMPLATE_DIR = Path(__file__).parent / "templates"
