@@ -1,3 +1,4 @@
+from connector.client import get_page
 from connector.generated import (
     FindEntitlementAssociationsRequest,
     FindEntitlementAssociationsResponse,
@@ -6,6 +7,8 @@ from connector.generated import (
     GetLastActivityResponse,
     ListAccountsRequest,
     ListAccountsResponse,
+    ListCustomAttributesSchemaRequest,
+    ListCustomAttributesSchemaResponse,
     ListEntitlementsRequest,
     ListEntitlementsResponse,
     ListResourcesRequest,
@@ -15,18 +18,15 @@ from connector.generated import (
     ValidateCredentialsResponse,
     ValidatedCredentials,
 )
-from connector.oai.capability import get_page, get_settings
 
-
-from {name}.pagination import DEFAULT_PAGE_SIZE, NextPageToken, Pagination
-from {name}.settings import {pascal}Settings
 from {name}.client import {pascal}Client
+from {name}.pagination import DEFAULT_PAGE_SIZE, NextPageToken, Pagination, paginations_from_args
 
 async def validate_credentials(
     args: ValidateCredentialsRequest,
 ) -> ValidateCredentialsResponse:
     async with {pascal}Client(args) as client:
-        #_ = await client.get_users()
+        # _ = await client.get_users()
 
         return ValidateCredentialsResponse(
             response=ValidatedCredentials(
@@ -37,56 +37,54 @@ async def validate_credentials(
 
 
 async def list_accounts(args: ListAccountsRequest) -> ListAccountsResponse:
-    endpoint = "/users"
-    try:
-        current_pagination = NextPageToken(get_page(args).token).paginations()[0]
-    except IndexError:
-        current_pagination = Pagination.default(endpoint)
+    paginations, current_pagination, page_size = paginations_from_args(
+        args, default_endpoints=["/users"]
+    )
 
-    page_size = get_page(args).size or DEFAULT_PAGE_SIZE
     async with {pascal}Client(args) as client:
         response = await client.get_users(
-            limit=page_size, offset=current_pagination.offset,
+            limit=page_size,
+            offset=current_pagination.offset,
         )
         accounts: list[FoundAccountData] = response.to_accounts()
 
-        next_pagination = []
         if True:
-            next_pagination.append(
+            paginations.append(
                 Pagination(
-                    endpoint=endpoint,
+                    endpoint=current_pagination.endpoint,
                     offset=current_pagination.offset + len(accounts),
                 )
             )
 
-        next_page_token = NextPageToken.from_paginations(next_pagination).token
-
     return ListAccountsResponse(
         response=accounts,
-        page=Page(
-            token=next_page_token,
-            size=page_size,
-        )
-        if next_page_token
+        page=NextPageToken.from_paginations(paginations).to_page(page_size)
+        if paginations
         else None,
     )
 
 
 async def list_resources(args: ListResourcesRequest) -> ListResourcesResponse:
-    raise NotImplementedError
+    raise NotImplementedError  # pragma: no cover
 
 
 async def list_entitlements(
     args: ListEntitlementsRequest,
 ) -> ListEntitlementsResponse:
-    raise NotImplementedError
+    raise NotImplementedError  # pragma: no cover
 
 
 async def find_entitlement_associations(
     args: FindEntitlementAssociationsRequest,
 ) -> FindEntitlementAssociationsResponse:
-    raise NotImplementedError
+    raise NotImplementedError  # pragma: no cover
 
 
 async def get_last_activity(args: GetLastActivityRequest) -> GetLastActivityResponse:
-    raise NotImplementedError
+    raise NotImplementedError  # pragma: no cover
+
+
+async def list_custom_attributes_schema(
+    args: ListCustomAttributesSchemaRequest,
+) -> ListCustomAttributesSchemaResponse:
+    raise NotImplementedError  # pragma: no cover
