@@ -4,23 +4,21 @@ from connector.generated import EntitlementType, ResourceType
 
 
 class {pascal}ResourceTypes(str, Enum):
-    GLOBAL_RESOURCE = "GLOBAL_RESOURCE"
+    # The global resource is implicit
+    pass
+
 
 class {pascal}EntitlementTypes(str, Enum):
-    GLOBAL_ROLE = "ROLE"
+    ROLE = "ROLE"
 
-resource_types: list[ResourceType] = [
-    ResourceType(
-        type_id={pascal}ResourceTypes.GLOBAL_RESOURCE,
-        type_label="Global Resource",
-    )
-]
+
+resource_types: list[ResourceType] = []
 
 entitlement_types: list[EntitlementType] = [
     EntitlementType(
-        type_id={pascal}EntitlementTypes.GLOBAL_ROLE,
+        type_id={pascal}EntitlementTypes.ROLE,
         type_label="Role",
-        resource_type_id="",
+        resource_type_id="",  # means that this entitlement is associated with the global resource
         min=0,
         # You can also set a max, if users can't have infinite of these entitlements
         # max=1,
