@@ -1,5 +1,6 @@
 import os
 import pathlib
+import re
 import sys
 
 from connector.oai.capability import StandardCapabilityName
@@ -55,8 +56,11 @@ def gather_cases(
 
     files = []
     for capability in capabilities_to_test:
-        pattern = f"test_{capability}_cases.py"
-        matching_files = tests_dir_path.rglob(pattern)
+        pattern = rf"test_(?:.+_)*?{capability}(?:_.+)*_cases.py"
+        compiled = re.compile(pattern)
+        matching_files = [
+            file for file in tests_dir_path.rglob("*.py") if compiled.fullmatch(file.name)
+        ]
 
         for file_path in matching_files:
             relative_path = file_path.relative_to(tests_dir_path)
@@ -95,7 +99,7 @@ def calculate_coverage(integration: Integration, cases: list[str]) -> tuple[bool
         capability
         for file in cases
         for capability in capabilities_to_test
-        if f"test_{capability}_cases" in file
+        if re.search(f"test_(?:.+_)*?{capability}(?:_.+)*_cases", file) is not None
     )
     required_capabilities = set(capability for capability in capabilities_to_test)
     missing_capabilities = required_capabilities - existing_capabilities
