@@ -11,9 +11,14 @@ class MockedResponse:
     headers: dict[str, str] | None = None
     request_json_body: dict[
         str, t.Any
-    ] | None = None  # for cases where we want to match the request body
+    ] | None = None  # for cases where we want to match JSON request body
+    request_bytes_body: bytes | None = None  # for cases where we want to match bytes request body
+    request_path: str | None = None  # for cases match the request body and request path
 
 
-ResponseBodyMap: t.TypeAlias = dict[str, dict[str, MockedResponse]] | None
+ResponseBodyMap: t.TypeAlias = (
+    t.Mapping[str, t.Mapping[str, MockedResponse] | list[MockedResponse]] | None
+)
+# ResponseBodyMap: t.TypeAlias = dict[str, dict[str, MockedResponse]] | None
 RequestHandler: t.TypeAlias = t.Callable[[httpx.Request], httpx.Response]
 ClientContextManager: t.TypeAlias = t.Callable[[str, str, RequestHandler], t.ContextManager[None]]
