@@ -2,7 +2,10 @@
 
 import typing as t
 
-from connector.generated import (
+from connector.oai.capability import CustomRequest, CustomResponse
+from connector.oai.integration import DescriptionData, Integration
+from connector.oai.modules.oauth_module_types import OAuthSettings
+from connector_sdk_types.generated import (
     AuthModel,
     BasicCredential,
     CapabilitySchema,
@@ -14,9 +17,6 @@ from connector.generated import (
     OAuthCredential,
     StandardCapabilityName,
 )
-from connector.oai.capability import CustomRequest, CustomResponse
-from connector.oai.integration import DescriptionData, Integration
-from connector.oai.modules.oauth_module_types import OAuthSettings
 
 from .shared_types import (
     AccioRequest,
@@ -38,6 +38,7 @@ def case_info() -> Case:
         exception_handlers=[],
         handle_errors=True,
         description_data=DescriptionData(
+            app_vendor_domain="test.com",
             user_friendly_name="test_info_cases.py",
             categories=[],
         ),
@@ -63,6 +64,7 @@ def case_info() -> Case:
     expected_info = InfoResponse(
         response=Info(
             app_id="test",
+            app_vendor_domain="test.com",
             version="0.1.0",
             capabilities=[
                 "accio",
@@ -158,6 +160,7 @@ def case_info() -> Case:
                         "title": "Password",
                         "type": "string",
                         "x-field_type": "SECRET",
+                        "x-secret": True,
                     },
                     "username": {
                         "description": "The username for basic auth.",
@@ -213,6 +216,7 @@ def case_info_with_credentials() -> Case:
         exception_handlers=[],
         handle_errors=True,
         description_data=DescriptionData(
+            app_vendor_domain="test.com",
             user_friendly_name="test_info_cases.py",
             categories=[],
         ),
@@ -239,6 +243,7 @@ def case_info_with_credentials() -> Case:
     expected_info = InfoResponse(
         response=Info(
             app_id="test",
+            app_vendor_domain="test.com",
             version="0.1.0",
             capabilities=[
                 "accio",
@@ -342,6 +347,7 @@ def case_info_with_credentials() -> Case:
                             "description": "The password for basic auth.",
                             "type": "string",
                             "x-field_type": "SECRET",
+                            "x-secret": True,
                         },
                     },
                     "required": ["username", "password"],
@@ -359,6 +365,7 @@ def case_info_with_credentials() -> Case:
                             "description": "The token for token-based auth.",
                             "type": "string",
                             "x-field_type": "SECRET",
+                            "x-secret": True,
                         },
                     },
                     "required": ["token"],
@@ -399,6 +406,7 @@ def case_info_with_scopes() -> Case:
         ),
         handle_errors=True,
         description_data=DescriptionData(
+            app_vendor_domain="test.com",
             user_friendly_name="test_info_cases.py",
             categories=[],
         ),
@@ -418,6 +426,7 @@ def case_info_with_scopes() -> Case:
     expected_info = InfoResponse(
         response=Info(
             app_id="test",
+            app_vendor_domain="test.com",
             version="0.1.0",
             capabilities=[
                 StandardCapabilityName.APP_INFO,
@@ -800,6 +809,7 @@ def case_info_with_scopes() -> Case:
                         "title": "Access Token",
                         "type": "string",
                         "x-field_type": "HIDDEN",
+                        "x-hidden": True,
                     },
                 },
                 "required": ["access_token"],
