@@ -2,20 +2,6 @@ from unittest.mock import AsyncMock, patch
 from urllib.parse import parse_qs, urlparse
 
 import pytest
-from connector.generated import (
-    AuthModel,
-    GetAuthorizationUrl,
-    GetAuthorizationUrlRequest,
-    HandleAuthorizationCallback,
-    HandleAuthorizationCallbackRequest,
-    HandleClientCredentials,
-    HandleClientCredentialsRequest,
-    OAuthClientCredential,
-    OAuthCredential,
-    RefreshAccessToken,
-    RefreshAccessTokenRequest,
-    StandardCapabilityName,
-)
 from connector.httpx_rewrite import AsyncClient
 from connector.oai.capability import AuthRequest, get_settings
 from connector.oai.errors import ConnectorError
@@ -30,6 +16,20 @@ from connector.oai.modules.oauth_module_types import (
     RequestDataType,
     RequestMethod,
 )
+from connector_sdk_types.generated import (
+    AuthModel,
+    GetAuthorizationUrl,
+    GetAuthorizationUrlRequest,
+    HandleAuthorizationCallback,
+    HandleAuthorizationCallbackRequest,
+    HandleClientCredentials,
+    HandleClientCredentialsRequest,
+    OAuthClientCredential,
+    OAuthCredential,
+    RefreshAccessToken,
+    RefreshAccessTokenRequest,
+    StandardCapabilityName,
+)
 from httpx import Request, Response
 from pydantic import BaseModel, ValidationError
 
@@ -317,9 +317,9 @@ async def test_get_authorization_url(integration):
     assert parsed_url.path == "/auth"
 
     assert "client_id=test_client_id" in parsed_url.query
-    assert "redirect_uri=https://test.example.com/callback" in parsed_url.query
+    assert "redirect_uri=https%3A%2F%2Ftest.example.com%2Fcallback" in parsed_url.query
     assert "state=test_state" in parsed_url.query
-    assert "scope=scope1 scope2 scope3" in parsed_url.query
+    assert "scope=scope1+scope2+scope3" in parsed_url.query
 
 
 @pytest.mark.asyncio
@@ -824,9 +824,9 @@ async def test_get_authorization_url_with_credentials(integration_with_credentia
     assert parsed_url.path == "/auth"
 
     assert "client_id=test_client_id" in parsed_url.query
-    assert "redirect_uri=https://test.example.com/callback" in parsed_url.query
+    assert "redirect_uri=https%3A%2F%2Ftest.example.com%2Fcallback" in parsed_url.query
     assert "state=test_state" in parsed_url.query
-    assert "scope=scope1 scope2 scope3" in parsed_url.query
+    assert "scope=scope1+scope2+scope3" in parsed_url.query
 
 
 @pytest.mark.asyncio
