@@ -3,16 +3,6 @@
 import typing as t
 
 import pytest
-from connector.generated import (
-    AccountStatus,
-    BasicCredential,
-    CreateAccountRequest,
-    CreateAccountResponse,
-    CreatedAccount,
-    ListAccountsRequest,
-    ListAccountsResponse,
-    StandardCapabilityName,
-)
 from connector.oai.capability import CapabilityCallableProto, CustomRequest, CustomResponse
 from connector.oai.integration import (
     DescriptionData,
@@ -20,6 +10,27 @@ from connector.oai.integration import (
     InvalidCapabilityNameError,
     ReservedCapabilityNameError,
 )
+from connector_sdk_types.generated import (
+    AccountStatus,
+    Amount,
+    BasicCredential,
+    CreateAccountRequest,
+    CreateAccountResponse,
+    CreatedAccount,
+    Expense,
+    ExpenseApprovalStatus,
+    ExpensePaymentStatus,
+    ExpenseType,
+    ListAccountsRequest,
+    ListAccountsResponse,
+    ListExpensesRequest,
+    ListExpensesResponse,
+    NormalizedExpenseApprovalStatus,
+    NormalizedExpensePaymentStatus,
+    SpendUser,
+    StandardCapabilityName,
+    Vendor,
+)
 
 from .shared_types import (
     AccioRequest,
@@ -62,6 +73,56 @@ def case_register_capability_success() -> Case:
     return capability_name.value, integration.capabilities
 
 
+def case_register_list_expenses_success() -> Case:
+    integration = new_integration()
+    capability_name = StandardCapabilityName.LIST_EXPENSES
+
+    @integration.register_capability(capability_name)
+    async def capability(
+        args: ListExpensesRequest,
+    ) -> ListExpensesResponse:
+        return ListExpensesResponse(
+            response=[
+                Expense(
+                    id="2652b217-d686-4277-aad5-37320e9d9912",
+                    report_id="bfc896e8-4bca-4aa4-87df-6341b22ed44d",
+                    transaction_date="2024-01-01T:00:00+00:00",
+                    payment_date="2024-01-03T:00:00+00:00",
+                    total_amount=Amount(
+                        amount="100.00",
+                        currency="USD",
+                    ),
+                    paid_amount=Amount(
+                        amount="100.00",
+                        currency="USD",
+                    ),
+                    seller=Vendor(
+                        id="f2d8d6a7-1a1a-4b3d-a092-936a7b32a0b3",
+                        name="Adobe",
+                        description="A leading software company known for its creativity products",
+                    ),
+                    description="Creative Cloud for the Marketing team",
+                    type=ExpenseType.REIMBURSEMENT,
+                    approval_status=ExpenseApprovalStatus(
+                        display_value="Approved",
+                        normalized_value=NormalizedExpenseApprovalStatus.APPROVED,
+                    ),
+                    payment_status=ExpensePaymentStatus(
+                        display_value="Paid",
+                        normalized_value=NormalizedExpensePaymentStatus.PAID,
+                    ),
+                    submitter=SpendUser(
+                        id="6da0e939-9ba9-497c-bf05-a86e95cbbb49",
+                        email="harry@hogwarts.edu",
+                    ),
+                )
+            ],
+            raw_data=None,
+        )
+
+    return capability_name.value, integration.capabilities
+
+
 def case_register_capability_with_metadata_success() -> Case:
     integration = new_integration()
     capability_name = StandardCapabilityName.CREATE_ACCOUNT
