@@ -3,7 +3,11 @@
 import typing as t
 
 import pytest_cases
-from connector.generated import (
+from connector.oai.capability import (
+    CapabilityCallableProto,
+    CustomRequest,
+)
+from connector_sdk_types.generated import (
     AssignedEntitlement,
     AssignEntitlement,
     AssignEntitlementResponse,
@@ -14,10 +18,7 @@ from connector.generated import (
     UpdateableAccount,
     UpdateAccountResponse,
 )
-from connector.oai.capability import (
-    CapabilityCallableProto,
-    CustomRequest,
-)
+from pydantic import BaseModel
 
 Case: t.TypeAlias = tuple[
     StandardCapabilityName,
@@ -142,3 +143,68 @@ def case_overridden_input_allowed_for_update_account() -> Case:
         )
 
     return StandardCapabilityName.UPDATE_ACCOUNT, update_account_for_specific_app
+
+
+@pytest_cases.case(tags=("invalid",))
+def case_overridden_input_changes_origin_property_type() -> Case:
+    """
+    You can't change the type of an existing property, when customizing an input.
+
+    E.g. no `email: int`
+    """
+
+    class AppSpecificUpdateAccount(UpdateableAccount):
+        # we're changing the type in a way that breaks
+        # the relation to the parent class. but this
+        # isn't a runtime python failure, just a type
+        # checking failure
+        id: int  # type: ignore
+
+    def update_account_for_specific_app(
+        args: CustomRequest[AppSpecificUpdateAccount],
+    ) -> UpdateAccountResponse:
+        return UpdateAccountResponse(
+            response=UpdateableAccount(id="response_id"),
+        )
+
+    return StandardCapabilityName.UPDATE_ACCOUNT, update_account_for_specific_app
+
+
+@pytest_cases.case(tags=("invalid",))
+def case_overridden_input_makes_required_field_optional() -> Case:
+    """
+    You can't make a previously required input property optional
+
+    E.g. no `id: str | None` when it was `id: str`
+    """
+
+    class AppSpecificUpdateAccount(UpdateableAccount):
+        id: str | None  # type: ignore
+
+    def update_account_for_specific_app(
+        args: CustomRequest[AppSpecificUpdateAccount],
+    ) -> UpdateAccountResponse:
+        return UpdateAccountResponse(
+            response=UpdateableAccount(id="response_id"),
+        )
+
+    return StandardCapabilityName.UPDATE_ACCOUNT, update_account_for_specific_app
+
+
+@pytest_cases.case(tags=("invalid",))
+def case_overridden_input_drops_a_field() -> Case:
+    """
+    You can't remove a previous input property
+    """
+
+    class AppSpecificUpdateAccount(BaseModel):
+        foo: str
+
+    def update_account_for_specific_app(
+        args: CustomRequest[AppSpecificUpdateAccount],
+    ) -> UpdateAccountResponse:
+        return UpdateAccountResponse(
+            response=UpdateableAccount(id="response_id"),
+        )
+
+    return StandardCapabilityName.UPDATE_ACCOUNT, update_account_for_specific_app
